==> terraform_validator-0.6.38-py3-none-any.whl: terraform_validator/custom_rules/SnsTopicPolicyNotActionRule.py <==
from __future__ import absolute_import, division, print_function
import inspect
import sys
from builtins import (str)
from terraform_validator.custom_rules.BaseRule import BaseRule

def lineno():
    """Returns the current line number in our program."""
    return str(' - SnsTopicPolicyNotActionRule - caller: '+str(inspect.stack()[1][3])+' - line number: '+str(inspect.currentframe().f_back.f_lineno))



class SnsTopicPolicyNotActionRule(BaseRule):

    def __init__(self, cfn_model=None, debug=None):
        """
        Initialize
        :param cfn_model:
        """
        BaseRule.__init__(self, cfn_model, debug=debug)

    def rule_text(self):
        """
        Get rule text
        :return:
        """
        if self.debug:
            print('rule_text'+lineno())
        return 'SNS Topic policy should not allow Allow+NotAction'


    def rule_type(self):
        """
        Get rule type
        :return:
        """
        self.type= 'VIOLATION::WARNING'
        return 'VIOLATION::WARNING'


    def rule_id(self):
        """
        Get rule id
        :return:
        """
        if self.debug:
            print('rule_id'+lineno())
        self.id ='W19'
        return 'W19'


    def audit_impl(self):
        """
        Audit
        :return: violations
        """
        if self.debug:
            print('SnsTopicPolicyNotActionRule - audit_impl'+lineno())

        violating_policies = []

        resources = self.cfn_model.resources_by_type('AWS::SNS::TopicPolicy')

        if len(resources)>0:
              for resource in resources:
                  if self.debug:
                      print('resource: '+str(resource)+lineno())
                      print('vars: '+str(vars(resource))+lineno())

                  if hasattr(resource,'policy_document'):

                      if resource.policy_document:
                            if self.debug:
                                print('policy_document: '+str(resource.policy_document))
                            if resource.policy_document.allows_not_action():

                                violating_policies.append(str(resource.logical_resource_id))

        else:
            if self.debug:
                print('no violating_policies' + lineno())

        return violating_policies

==> terraform_validator-0.6.41-py3-none-any.whl: terraform_validator/custom_rules/SnsTopicPolicyNotActionRule.py <==
from __future__ import absolute_import, division, print_function
import inspect
import sys
from builtins import (str)
from terraform_validator.custom_rules.BaseRule import BaseRule

def lineno():
    """Returns the current line number in our program."""
    return str(' - SnsTopicPolicyNotActionRule - caller: '+str(inspect.stack()[1][3])+' - line number: '+str(inspect.currentframe().f_back.f_lineno))



class SnsTopicPolicyNotActionRule(BaseRule):

    def __init__(self, cfn_model=None, debug=None):
        """
        Initialize
        :param cfn_model:
        """
        BaseRule.__init__(self, cfn_model, debug=debug)

    def rule_text(self):
        """
        Get rule text
        :return:
        """
        if self.debug:
            print('rule_text'+lineno())
        return 'SNS Topic policy should not allow Allow+NotAction'


    def rule_type(self):
        """
        Get rule type
        :return:
        """
        self.type= 'VIOLATION::WARNING'
        return 'VIOLATION::WARNING'


    def rule_id(self):
        """
        Get rule id
        :return:
        """
        if self.debug:
            print('rule_id'+lineno())
        self.id ='W19'
        return 'W19'


    def audit_impl(self):
        """
        Audit
        :return: violations
        """
        if self.debug:
            print('SnsTopicPolicyNotActionRule - audit_impl'+lineno())

        violating_policies = []

        resources = self.cfn_model.resources_by_type('AWS::SNS::TopicPolicy')

        if len(resources)>0:
              for resource in resources:
                  if self.debug:
                      print("\n##################################")
                      print('resource: '+str(resource)+lineno())
                      print('vars: '+str(vars(resource))+lineno())

                  if hasattr(resource,'policy_document') and resource.policy_document:

                      if resource.policy_document:
                            if self.debug:
                                print('policy_document: '+str(resource.policy_document))
                            if resource.policy_document.allows_not_action():

                                violating_policies.append(str(resource.logical_resource_id))
                  elif hasattr(resource,'policy') and resource.policy:

                      if resource.policy:
                            if self.debug:
                                print('policy: '+str(resource.policy_document))
                            if resource.policy.allows_not_action():

                                violating_policies.append(str(resource.logical_resource_id))

        else:
            if self.debug:
                print('no violating_policies' + lineno())

        return violating_policies
